@@ -18,7 +18,7 @@
 #
 #=============================================================================
 
-package Term::CLI::Command 0.058002;
+package Term::CLI::Command 0.059000;
 
 use 5.014;
 use warnings;
@@ -58,8 +58,16 @@ sub option_names {
     my $opt_specs = $self->options or return ();
     my @names;
     for my $spec ( @{$opt_specs} ) {
-        for my $optname ( split( qr{\|}x, $spec =~ s/^([^!+=:]+).*/$1/rx ) ) {
-            push @names, length($optname) == 1 ? "-$optname" : "--$optname";
+        my ($name_spec, $opts) = $spec =~ m{^ ([^!+=:]+) (.*) $}xms;
+        my $negatable = index($opts, '!') >= 0;
+        for my $opt_name ( split( qr{\|}x, $name_spec) ) {
+            if (length $opt_name > 1) {
+                push @names, "--$opt_name";
+                push @names, "--no-$opt_name" if $negatable;
+            }
+            else {
+                push @names, "-$opt_name";
+            }
         }
     }
     return @names;
@@ -323,7 +331,7 @@ Term::CLI::Command - Class for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.058002
+version 0.059000
 
 =head1 SYNOPSIS
 
